TCTI
====

.. automodule:: tpm2_pytss.TCTI
   :members: TCTI
   :undoc-members:

.. automodule:: tpm2_pytss.TCTILdr
   :members: TCTILdr
   :undoc-members:

.. automodule:: tpm2_pytss.PyTCTI
   :members: TCTILdr
   :undoc-members:
